searchData={"items":[{"type":"module","title":"PortServer","doc":"The main module exposing the public API of PortServer\n\nPortServer is a standard GenServer implementation.\nIt can be started manually or through a supervision tree.\nYou can interact with it through `call/3` or `cast/3`.","ref":"PortServer.html"},{"type":"function","title":"PortServer.call/4","doc":"Makes a synchronous call to the `server` and waits for its reply.\n\nSimilar to `GenServer.call/3`\n\n`msg` is the handler name to be called.\n\n`payload` can be any term the can be jsonized.\n\n```elixir\nreply = PortServer.call(pid, \"func\", %{\n    p1=> \"hello\",\n    p2=> 100\n  })\n```","ref":"PortServer.html#call/4"},{"type":"function","title":"PortServer.cast/3","doc":"Casts a request to the `server` without waiting for a response.\n\nSimilar to `GenServer.cast/2`\n\n`msg` is the handler name to be cast.\n\n`payload` can be any term the can be jsonized.\n\n```elixir\nPortServer.cast(pid, \"event\", %{\n    p1=> \"hello\",\n    p2=> 100\n  })\n```","ref":"PortServer.html#cast/3"},{"type":"function","title":"PortServer.start/2","doc":"Start PortServer by running a command.\n\nThe command is consists of three parts: {\"command\", \"arguments\", \"options\"}\n\n```elixir\n#\n{:ok, pid} = PortServer.start({\"node\", [\"./index.js\"], [dir: \"../\"]})\n```\n\nAvailable options:\n\n  * `:dir` - current working directory.\n\n  * `:env` - environment variables.\n\n  * `:start_timeout` - Port server must start within the specified time.\n    Otherwise, it will be considered as a initialization failure.","ref":"PortServer.html#start/2"},{"type":"function","title":"PortServer.start_link/2","doc":"Similar to `start/2` except it will call `GenServer.start_link/3` instead of\n`GenServer.start/3`","ref":"PortServer.html#start_link/2"},{"type":"type","title":"PortServer.command/0","doc":"","ref":"PortServer.html#t:command/0"},{"type":"extras","title":"PortServer","doc":"# PortServer\r\n\r\nBy using PortServer, you can implement a GenServer using NodeJS.\r\n\r\nFeatures:\r\n\r\n- Support `call`, `cast` and `monitor` function of GenServer.\r\n\r\n- `call` can be handled asynchronously in NodeJS.","ref":"readme.html"},{"type":"extras","title":"Installation - PortServer","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"Elixir - PortServer","doc":"Add PortServer as dependency to your Mix project:\r\n\r\n```elixir\r\ndef deps do\r\n  [{:port_server, \"~> 0.1.0\"}]\r\nend\r\n```","ref":"readme.html#elixir"},{"type":"extras","title":"NodeJS - PortServer","doc":"```\r\nnpm install port-server\r\n```","ref":"readme.html#nodejs"},{"type":"extras","title":"Usage - PortServer","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Implement `call` using NodeJS - PortServer","doc":"JS\r\n\r\n```javascript\r\nconst server = require(\"port-server\")\r\n\r\nserver.onCall(\"hello\", (pid, tag, payload) => {\r\n  server.reply(pid, tag, \"hello \" + payload)\r\n})\r\nserver.start()\r\n```\r\n\r\nElixir\r\n\r\n```elixir\r\niex> {:ok, pid} = PortServer.start({\"node\", [\"index.js\"],[]})\r\n{:ok, #PID<0.195.0>}\r\niex> PortServer.call(pid, \"hello\", \"world\")\r\n\"hello world\"\r\n```\r\n\r\n`call` can be handled asynchronously.\r\nAn \"async\" call handling will not block others.\r\nIt means that calling from multiple processes will be handled concurrently.\r\n\r\n```javascript\r\nconst server = require(\"port-server\")\r\n\r\nserver.onCall(\"hello\", (pid, tag, payload) => {\r\n  setTimeout(() => {\r\n    server.reply(pid, tag, \"hello \" + payload)\r\n  }, 5000)\r\n})\r\nserver.start()\r\n```","ref":"readme.html#implement-call-using-nodejs"},{"type":"extras","title":"Implement `cast` using NodeJS - PortServer","doc":"JS\r\n\r\n```javascript\r\nconst server = require(\"port-server\")\r\n\r\nserver.onCast(\"ping\", (pid, payload) => {\r\n  server.cast(pid, \"pong \", payload)\r\n})\r\nserver.start()\r\n```\r\n\r\nElixir\r\n\r\n```elixir\r\niex> {:ok, pid} = PortServer.start({\"node\", [\"index.js\"],[]})\r\n{:ok, #PID<0.195.0>}\r\niex> PortServer.cast(pid, \"ping\", \"123\")\r\n:ok\r\niex> flush\r\n{:\"$gen_cast\", {\"pong\", \"123\"}}\r\n:ok\r\n```","ref":"readme.html#implement-cast-using-nodejs"},{"type":"extras","title":"Implement `monitor` using NodeJS - PortServer","doc":"JS\r\n\r\n```javascript\r\nconst server = require(\"port-server\")\r\n\r\nfunction down(pid) {\r\n  // handle Pid `DOWN` event.\r\n  console.log(`Pid(${pid}) is down!`)\r\n}\r\n\r\nserver.onCast(\"test_monitor\", (pid, payload) => {\r\n  server.monitor(pid, down)\r\n})\r\n\r\nserver.start()\r\n```","ref":"readme.html#implement-monitor-using-nodejs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}